@@ -1,6 +1,6 @@
 /*
     This file is part of darktable,
-    Copyright (C) 2009-2024 darktable developers.
+    Copyright (C) 2009-2025 darktable developers.
 
     darktable is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -33,17 +33,6 @@
 #include <arm_neon.h>
 #endif
 
-G_BEGIN_DECLS
-
-/** region of interest, needed by pixelpipe.h */
-typedef struct dt_iop_roi_t
-{
-  int x, y, width, height;
-  float scale;
-} dt_iop_roi_t;
-
-G_END_DECLS
-
 #include "develop/pixelpipe.h"
 #include "dtgtk/togglebutton.h"
 
@@ -59,13 +48,6 @@ G_END_DECLS
 
 G_BEGIN_DECLS
 
-struct dt_develop_t;
-struct dt_dev_pixelpipe_t;
-struct dt_dev_pixelpipe_iop_t;
-struct dt_develop_blend_params_t;
-struct dt_develop_tiling_t;
-struct dt_iop_color_picker_t;
-
 /** module group */
 typedef enum dt_iop_group_t
 {
@@ -119,7 +101,9 @@ typedef enum dt_iop_flags_t
   IOP_FLAGS_GUIDES_SPECIAL_DRAW = 1 << 14, // handle the grid drawing directly
   IOP_FLAGS_GUIDES_WIDGET = 1 << 15,     // require the guides widget
   IOP_FLAGS_CROP_EXPOSER = 1 << 16,      // offers crop exposing
-  IOP_FLAGS_EXPAND_ROI_IN = 1 << 17      // we might have to take special care about roi expansion
+  IOP_FLAGS_EXPAND_ROI_IN = 1 << 17,     // we might have to take special care about roi expansion
+  IOP_FLAGS_WRITE_DETAILS = 1 << 18,     // provides the scharr mask used by details
+  IOP_FLAGS_WRITE_RASTER = 1 << 19       // modules not supporting blending might still advertise a raster mask
 } dt_iop_flags_t;
 
 /** status of a module*/
@@ -134,6 +118,7 @@ typedef enum dt_iop_module_state_t
 typedef void dt_iop_gui_data_t;
 typedef void dt_iop_data_t;
 typedef void dt_iop_global_data_t;
+typedef void dt_iop_module_data_t;
 
 /** color picker request */
 typedef enum dt_dev_request_colorpick_flags_t
@@ -194,6 +179,8 @@ typedef struct dt_iop_module_t
   int32_t instance;
   /** order of the module on the pipe. the pipe will be sorted by iop_order. */
   int iop_order;
+  /** position id of module in pipe */
+  int position;
   /** module sets this if the enable checkbox should be hidden. */
   gboolean hide_enable_button;
   /** set to DT_REQUEST_COLORPICK_MODULE if you want an input color
@@ -238,6 +225,8 @@ typedef struct dt_iop_module_t
   dt_pthread_mutex_t gui_lock;
   /** other stuff that may be needed by the module, not only in gui mode. */
   dt_iop_global_data_t *global_data;
+  /** data that must be available per module instance */
+  dt_iop_module_data_t *data;
   /** blending params */
   struct dt_develop_blend_params_t *blend_params, *default_blendop_params;
   /** holder for blending ui control */
@@ -412,8 +401,12 @@ GtkWidget *dt_iop_gui_header_button(dt_iop_module_t *module,
 
 /** requests the focus for this plugin (to draw overlays over the center image) */
 void dt_iop_request_focus(dt_iop_module_t *module);
+/** returns TRUE if tested module has focus */
+gboolean dt_iop_has_focus(const dt_iop_module_t *module);
 /** allocate and load default settings from introspection. */
 void dt_iop_default_init(dt_iop_module_t *module);
+/** helper for module cleanup to do the basic stuff */
+void dt_iop_default_cleanup(dt_iop_module_t *module);
 /** loads default settings from database. */
 void dt_iop_load_default_params(dt_iop_module_t *module);
 /** creates the module's gui widget */
@@ -483,15 +476,18 @@ void dt_iop_update_multi_priority(dt_iop_module_t *module, int new_priority);
 
 /** iterates over the users hash table and checks if a specific mask is being used */
 gboolean dt_iop_is_raster_mask_used(const dt_iop_module_t *module, const dt_mask_id_t id);
+/** checks dt_iop_is_raster_mask_used() or writing for exports */
+gboolean dt_iop_piece_is_raster_mask_used(const struct dt_dev_pixelpipe_iop_t *piece, const dt_mask_id_t id);
+
+/** set and clear the rastermasks, check the pixelpipe cache and report */
+void dt_iop_piece_set_raster(struct dt_dev_pixelpipe_iop_t *piece, float *mask, const dt_iop_roi_t *const roi_in, const dt_iop_roi_t *const roi_out);
+void dt_iop_piece_clear_raster(struct dt_dev_pixelpipe_iop_t *piece, float *mask);
 
 /** returns the previous visible module on the module list */
 dt_iop_module_t *dt_iop_gui_get_previous_visible_module(const dt_iop_module_t *module);
 /** returns the next visible module on the module list */
 dt_iop_module_t *dt_iop_gui_get_next_visible_module(const dt_iop_module_t *module);
 
-// initializes memory.darktable_iop_names
-void dt_iop_set_darktable_iop_table();
-
 /** adds keyboard accels to the first module in the pipe to handle
  * where there are multiple instances */
 void dt_iop_connect_accels_multi(dt_iop_module_so_t *module);
@@ -541,15 +537,11 @@ static inline dt_iop_gui_data_t *_iop_gui_alloc(dt_iop_module_t *module, const s
 {
   // Align so that DT_ALIGNED_ARRAY may be used within gui_data struct
   module->gui_data = dt_calloc_aligned(size);
-  dt_pthread_mutex_init(&module->gui_lock, NULL);
   return module->gui_data;
 }
 #define IOP_GUI_ALLOC(module) \
   (dt_iop_##module##_gui_data_t *)_iop_gui_alloc(self,sizeof(dt_iop_##module##_gui_data_t))
 
-#define IOP_GUI_FREE \
-  dt_pthread_mutex_destroy(&self->gui_lock);if(self->gui_data){dt_free_align(self->gui_data);} self->gui_data = NULL
-
 /** check whether we have the required number of channels in the input
  ** data; if not, copy the input buffer to the output buffer, set the
  ** module's trouble message, and return FALSE */
