@@ -15,9 +15,6 @@
     You should have received a copy of the GNU General Public License
     along with darktable.  If not, see <http://www.gnu.org/licenses/>.
 */
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
 // our includes go first:
 #include "bauhaus/bauhaus.h"
 #include "develop/imageop.h"
@@ -127,7 +124,7 @@ const char *name()
 
 // a routine returning the description of the module. this is
 // displayed when the mouse is over the module's header.
-const char **description(struct dt_iop_module_t *self)
+const char **description(dt_iop_module_t *self)
 {
   return dt_iop_set_description
     (self,
@@ -216,8 +213,7 @@ int legacy_params(dt_iop_module_t *self,
     } dt_iop_basecurve_params_v5_t;
 
     dt_iop_useless_params_v2_t *o = (dt_iop_useless_params_v2_t *)old_params;
-    dt_iop_useless_params_v3_t *n =
-      (dt_iop_useless_params_v3_t *)malloc(sizeof(dt_iop_useless_params_v3_t));
+    dt_iop_useless_params_v3_t *n = malloc(sizeof(dt_iop_useless_params_v3_t));
     memcpy(n, o, sizeof(dt_iop_useless_params_v2_t));
     n->strength = 1;
 
@@ -253,11 +249,11 @@ void commit_params(dt_iop_module_t *self,
     IOP_FLAGS_ALLOW_TILING Also define this if the module uses more
     memory on the OpenCl device than the in& output buffers.
 */
-void tiling_callback(struct dt_iop_module_t *self,
-                     struct dt_dev_pixelpipe_iop_t *piece,
+void tiling_callback(dt_iop_module_t *self,
+                     dt_dev_pixelpipe_iop_t *piece,
                      const dt_iop_roi_t *roi_in,
                      const dt_iop_roi_t *roi_out,
-                     struct dt_develop_tiling_t *tiling)
+                     dt_develop_tiling_t *tiling)
 {
   tiling->factor = 2.0f;    // input buffer + output buffer; increase
                             // if additional memory allocated
@@ -274,9 +270,9 @@ void tiling_callback(struct dt_iop_module_t *self,
 #endif
 
 /** modify regions of interest (optional, per pixel ops don't need this) */
-// void modify_roi_out(struct dt_iop_module_t *self, struct dt_dev_pixelpipe_iop_t *piece, dt_iop_roi_t
+// void modify_roi_out(dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, dt_iop_roi_t
 // *roi_out, const dt_iop_roi_t *roi_in);
-// void modify_roi_in(struct dt_iop_module_t *self, struct dt_dev_pixelpipe_iop_t *piece, const dt_iop_roi_t
+// void modify_roi_in(dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, const dt_iop_roi_t
 // *roi_out, dt_iop_roi_t *roi_in);
 
 #if 0
@@ -287,7 +283,7 @@ gboolean distort_transform(dt_iop_module_t *self,
                            float *points,
                            const size_t points_count)
 {
-  const dt_iop_useless_params_t *d = (dt_iop_useless_params_t *)piece->data;
+  const dt_iop_useless_params_t *d = piece->data;
 
   const float adjx = 0.0 * d->factor;
   const float adjy = 0.0;
@@ -314,7 +310,7 @@ gboolean distort_backtransform(dt_iop_module_t *self,
                                float *points,
                                const size_t points_count)
 {
-  const dt_iop_useless_params_t *d = (dt_iop_useless_params_t *)piece->data;
+  const dt_iop_useless_params_t *d = piece->data;
 
   const float adjx = 0.0 * d->factor;
   const float adjy = 0.0;
@@ -334,7 +330,7 @@ gboolean distort_backtransform(dt_iop_module_t *self,
 #endif
 
 /** modify a mask according to the pixel shifts the module applies (optional, per-pixel ops don't need this) */
-// void distort_mask(struct dt_iop_module_t *self, struct dt_dev_pixelpipe_iop_t *piece, const float *const in,
+// void distort_mask(dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, const float *const in,
 // float *const out, const dt_iop_roi_t *const roi_in, const dt_iop_roi_t *const roi_out);
 
 /** process, all real work is done here.
@@ -344,7 +340,7 @@ gboolean distort_backtransform(dt_iop_module_t *self,
           a signal should be used (raise a signal here) and a corresponding callback
           must be connected to this signal.
 */
-void process(struct dt_iop_module_t *self,
+void process(dt_iop_module_t *self,
              dt_dev_pixelpipe_iop_t *piece,
              const void *const ivoid,
              void *const ovoid,
@@ -353,7 +349,7 @@ void process(struct dt_iop_module_t *self,
 {
   // this is called for preview and full pipe separately, each with
   // its own pixelpipe piece.  get our data struct:
-  dt_iop_useless_params_t *d = (dt_iop_useless_params_t *)piece->data;
+  dt_iop_useless_params_t *d = piece->data;
   // the total scale is composed of scale before input to the pipeline (iscale),
   // and the scale of the roi.
   const float scale = piece->iscale / roi_in->scale;
@@ -363,7 +359,7 @@ void process(struct dt_iop_module_t *self,
   // most modules only support a single type of input data, so we can
   // check whether that format has been supplied and simply pass along
   // the data if not (setting a trouble flag to inform the user)
-  dt_iop_useless_gui_data_t *g = (dt_iop_useless_gui_data_t *)self->gui_data;
+  dt_iop_useless_gui_data_t *g = self->gui_data;
   if(!dt_iop_have_required_input_format(4 /*we need full-color pixels*/,
                                         self, piece->colors,
                                          ivoid, ovoid, roi_in, roi_out))
@@ -371,8 +367,7 @@ void process(struct dt_iop_module_t *self,
 
   // we create a raster mask as an example
   float *mask = NULL;
-  if(piece->pipe->store_all_raster_masks
-     || dt_iop_is_raster_mask_used(piece->module, mask_id))
+  if(dt_iop_piece_is_raster_mask_used(piece, mask_id))
   {
     // Attempt to allocate all of the buffers we need.  For this
     // example, we need one buffer that is equal in dimensions to the
@@ -435,7 +430,7 @@ void process(struct dt_iop_module_t *self,
 }
 
 /** Optional init and cleanup */
-void init(dt_iop_module_t *module)
+void init(dt_iop_module_t *self)
 {
   // Allocates memory for a module instance and fills default_params.
   // If this callback is not provided, the standard implementation in
@@ -448,36 +443,33 @@ void init(dt_iop_module_t *module)
   // initialisation.  The values in params will not be used and
   // default_params can be overwritten by reload_params on a per-image
   // basis.
-  dt_iop_default_init(module);
+  dt_iop_default_init(self);
 
   // Any non-default settings; for example disabling the on/off switch:
-  module->hide_enable_button = TRUE;
+  self->hide_enable_button = TRUE;
   // To make this work correctly, you also need to hide the widgets,
   // otherwise moving one would enable the module anyway. The standard
   // way is to set up a gtk_stack and show the page that only has a
   // label with an explanatory text when the module can't be used.
 }
 
-void init_global(dt_iop_module_so_t *module)
+void init_global(dt_iop_module_so_t *self)
 {
-  module->data = malloc(sizeof(dt_iop_useless_global_data_t));
+  self->data = malloc(sizeof(dt_iop_useless_global_data_t));
 }
 
-void cleanup(dt_iop_module_t *module)
+void cleanup(dt_iop_module_t *self)
 {
+  dt_iop_default_cleanup(self);
   // Releases any memory allocated in init(module) Implement this
   // function explicitly if the module allocates additional memory
   // besides (default_)params.  this is rare.
-  free(module->params);
-  module->params = NULL;
-  free(module->default_params);
-  module->default_params = NULL;
 }
 
-void cleanup_global(dt_iop_module_so_t *module)
+void cleanup_global(dt_iop_module_so_t *self)
 {
-  free(module->data);
-  module->data = NULL;
+  free(self->data);
+  self->data = NULL;
 }
 
 /** Put your local callbacks here, be sure to make them static so they
@@ -488,8 +480,8 @@ static void extra_callback(GtkWidget *w,
   // this is important to avoid cycles!
   if(darktable.gui->reset) return;
 
-  dt_iop_useless_params_t *p = (dt_iop_useless_params_t *)self->params;
-  dt_iop_useless_gui_data_t *g = (dt_iop_useless_gui_data_t *)self->gui_data;
+  dt_iop_useless_params_t *p = self->params;
+  dt_iop_useless_gui_data_t *g = self->gui_data;
 
   float extra = dt_bauhaus_slider_get(w);
 
@@ -513,8 +505,8 @@ void gui_changed(dt_iop_module_t *self,
   // (created with dt_bauhaus_..._from_params) are changed.
   // The updated value from the widget is already set in params.
   // any additional side-effects can be achieved here.
-  dt_iop_useless_params_t *p = (dt_iop_useless_params_t *)self->params;
-  dt_iop_useless_gui_data_t *g = (dt_iop_useless_gui_data_t *)self->gui_data;
+  dt_iop_useless_params_t *p = self->params;
+  dt_iop_useless_gui_data_t *g = self->gui_data;
 
   // Test which widget was changed.
   // If allowing w == NULL, this can be called from gui_update, so that
@@ -532,8 +524,8 @@ void color_picker_apply(dt_iop_module_t *self,
                         GtkWidget *picker,
                         dt_dev_pixelpipe_t *pipe)
 {
-  dt_iop_useless_params_t *p = (dt_iop_useless_params_t *)self->params;
-  dt_iop_useless_gui_data_t *g = (dt_iop_useless_gui_data_t *)self->gui_data;
+  dt_iop_useless_params_t *p = self->params;
+  dt_iop_useless_gui_data_t *g = self->gui_data;
 
   // This automatically gets called when any of the color pickers set up with
   // dt_color_picker_new in gui_init is used. If there is more than one,
@@ -560,8 +552,8 @@ void gui_update(dt_iop_module_t *self)
   // handled by gui_changed (and the automatic callback) for
   // introspection based widgets or by the explicit callback set up
   // manually (see example of extra_callback above).
-  dt_iop_useless_gui_data_t *g = (dt_iop_useless_gui_data_t *)self->gui_data;
-  dt_iop_useless_params_t *p = (dt_iop_useless_params_t *)self->params;
+  dt_iop_useless_gui_data_t *g = self->gui_data;
+  dt_iop_useless_params_t *p = self->params;
 
   // introspection based bauhaus widgets, created with
   // dt_bauhaus_slider_from_params or dt_bauhaus_combobox_from_params,
@@ -583,23 +575,23 @@ void gui_update(dt_iop_module_t *self)
 
 /** optional: if this exists, it will be called to init new defaults if a new image is
  * loaded from film strip mode. */
-void reload_defaults(dt_iop_module_t *module)
+void reload_defaults(dt_iop_module_t *self)
 {
   // This only has to be provided if module settings or default_params
   // need to depend on image type (raw?) or exif data.  Make sure to
   // always reset to the default for non-special cases, otherwise the
   // override will stick when switching to another image.
-  dt_iop_useless_params_t *d = (dt_iop_useless_params_t *)module->default_params;
+  dt_iop_useless_params_t *d = self->default_params;
 
   // As an example, switch off for non-raw images. The enable button
   // was already hidden in init().
-  if(!dt_image_is_raw(&module->dev->image_storage))
+  if(!dt_image_is_raw(&self->dev->image_storage))
   {
-    module->default_enabled = FALSE;
+    self->default_enabled = FALSE;
   }
   else
   {
-    module->default_enabled = TRUE;
+    self->default_enabled = TRUE;
     d->checker_scale = 3; // something dependent on exif, for example.
   }
 
@@ -609,7 +601,7 @@ void reload_defaults(dt_iop_module_t *module)
   // the default values in widgets. Resetting the individual widgets
   // will then have the same effect as resetting the whole module at
   // once.
-  dt_iop_useless_gui_data_t *g = (dt_iop_useless_gui_data_t *)module->gui_data;
+  dt_iop_useless_gui_data_t *g = self->gui_data;
   if(g)
   {
     dt_bauhaus_slider_set_default(g->scale, d->checker_scale);
@@ -702,13 +694,7 @@ void gui_init(dt_iop_module_t *self)
 void gui_cleanup(dt_iop_module_t *self)
 {
   // This only needs to be provided if gui_init allocates any memory
-  // or resources besides self->widget and gui_data_t. The default
-  // function (if an explicit one isn't provided here) takes care of
-  // gui_data_t (and gtk destroys the widget anyway). If you override
-  // the default, you have to do whatever you have to do, and also
-  // call IOP_GUI_FREE to clean up gui_data_t.
-
-  IOP_GUI_FREE;
+  // or resources besides self->widget and gui_data_t.
 }
 
 /** additional, optional callbacks to capture darkroom center events. */
@@ -717,7 +703,7 @@ void gui_cleanup(dt_iop_module_t *self)
 // int mouse_moved(dt_iop_module_t *self, double x, double y, double pressure, int which);
 // int button_pressed(dt_iop_module_t *self, double x, double y, double pressure, int which, int type,
 // uint32_t state);
-// int button_released(struct dt_iop_module_t *self, double x, double y, int which, uint32_t state);
+// int button_released(dt_iop_module_t *self, double x, double y, int which, uint32_t state);
 // int scrolled(dt_iop_module_t *self, double x, double y, int up, uint32_t state);
 
 // optional: if mouse events are handled by the iop, we can add text to the help screen by declaring
